#define _GNU_SOURCE
#include <stdlib.h>

int
main ()
{
    char *found;
    char *string;

    found = canonicalize_file_name (string);
}
